@@ -74,6 +74,10 @@ class mongodb(object):
         self.is_login = True
         return True
 
+    def drop(self):
+        log("删除{}".format(str(self)), level=self.level)
+        self._table.drop()
+
     def __repr__(self):
         return "mongodb://{host}:{port}/{db}/{table}".format( **self.__dict__)
 
